@@ -103,6 +103,9 @@
 
 #if defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100009
 #  define MRN_HAVE_TDC_ACQUIRE_SHARE
+#  if MYSQL_VERSION_ID < 100200
+#    define MRN_TDC_ACQUIRE_SHARE_REQUIRE_KEY
+#  endif
 #endif
 
 #if MYSQL_VERSION_ID >= 50613
@@ -243,7 +246,7 @@
 #  define MRN_ABORT_ON_WARNING(thd) thd->abort_on_warning
 #else
 #  if MYSQL_VERSION_ID >= 50706
-#    define MRN_ABORT_ON_WARNING(thd) false
+#    define MRN_ABORT_ON_WARNING(thd) thd->is_strict_mode()
 #  else
 #    define MRN_ABORT_ON_WARNING(thd) thd->abort_on_warning
 #  endif
@@ -289,4 +292,35 @@
                flags)
 #endif
 
+#if defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100000
+#  define mrn_strconvert(from_cs,               \
+                         from,                  \
+                         from_length,           \
+                         to_cs,                 \
+                         to,                    \
+                         to_length,             \
+                         errors)                \
+  strconvert((from_cs),                         \
+             (from),                            \
+             (from_length),                     \
+             (to_cs),                           \
+             (to),                              \
+             (to_length),                       \
+             (errors))
+#else
+#  define mrn_strconvert(from_cs,               \
+                         from,                  \
+                         from_length,           \
+                         to_cs,                 \
+                         to,                    \
+                         to_length,             \
+                         errors)                \
+  strconvert((from_cs),                         \
+             (from),                            \
+             (to_cs),                           \
+             (to),                              \
+             (to_length),                       \
+             (errors))
+#endif
+
 #endif /* MRN_MYSQL_COMPAT_H_ */
