@@ -579,7 +579,7 @@ int mrn_add_index_param(MRN_SHARE *share, KEY *key_info, int i)
         MRN_PARAM_STR_LIST("table", index_table, i);
         break;
       case 6:
-        push_warning_printf(thd, Sql_condition::WARN_LEVEL_WARN, 
+        push_warning_printf(thd, MRN_SEVERITY_WARNING,
                             ER_WARN_DEPRECATED_SYNTAX,
                             ER(ER_WARN_DEPRECATED_SYNTAX),
                             "parser", "tokenizer");
@@ -1003,29 +1003,34 @@ int mrn_free_share(MRN_SHARE *share)
 
 TABLE_SHARE *mrn_get_table_share(TABLE_LIST *table_list, int *error)
 {
-  uint key_length;
   TABLE_SHARE *share;
   THD *thd = current_thd;
   MRN_DBUG_ENTER_FUNCTION();
-#ifdef MRN_HAVE_GET_TABLE_DEF_KEY
+#if defined(MRN_HAVE_TDC_ACQUIRE_SHARE) &&      \
+  !defined(MRN_TDC_ACQUIRE_SHARE_REQUIRE_KEY)
+  share = tdc_acquire_share(thd, table_list, GTS_TABLE);
+#else
+  uint key_length;
+#  ifdef MRN_HAVE_GET_TABLE_DEF_KEY
   const char *key;
   key_length = get_table_def_key(table_list, &key);
-#else
+#  else
   char key[MAX_DBKEY_LENGTH];
   key_length = create_table_def_key(thd, key, table_list, FALSE);
-#endif
-#ifdef MRN_HAVE_TABLE_DEF_CACHE
+#  endif
+#  ifdef MRN_HAVE_TABLE_DEF_CACHE
   my_hash_value_type hash_value;
   hash_value = my_calc_hash(mrn_table_def_cache, (uchar*) key, key_length);
   share = get_table_share(thd, table_list, key, key_length, 0, error,
                           hash_value);
-#elif defined(MRN_HAVE_TDC_ACQUIRE_SHARE)
+#  elif defined(MRN_HAVE_TDC_ACQUIRE_SHARE)
   share = tdc_acquire_share(thd, table_list->db, table_list->table_name, key,
                             key_length,
                             table_list->mdl_request.key.tc_hash_value(),
                             GTS_TABLE, NULL);
-#else
+#  else
   share = get_table_share(thd, table_list, key, key_length, 0, error);
+#  endif
 #endif
   DBUG_RETURN(share);
 }
@@ -1056,7 +1061,7 @@ TABLE_SHARE *mrn_create_tmp_table_share(TABLE_LIST *table_list, const char *path
     *error = ER_CANT_OPEN_FILE;
     DBUG_RETURN(NULL);
   }
-  share->tmp_table = INTERNAL_TMP_TABLE; // TODO: is this right?
+  share->tmp_table = NO_TMP_TABLE; // TODO: is this right?
   share->path.str = (char *) path;
   share->path.length = strlen(share->path.str);
   share->normalized_path.str = mrn_my_strdup(path, MYF(MY_WME));
